@@ -79,48 +79,90 @@ __END__
 
 =head1 NAME
 
-Lingua::YaTeA::ChunkingDataSubset - Perl extension for ???
+Lingua::YaTeA::ChunkingDataSubset - Perl extension for subset of chuncking data.
 
 =head1 SYNOPSIS
 
   use Lingua::YaTeA::ChunkingDataSubset;
-  Lingua::YaTeA::ChunkingDataSubset->();
+  Lingua::YaTeA::ChunkingDataSubset->new();
 
 =head1 DESCRIPTION
 
+The module implements subsets of chunking data, i.e. chunking
+frontiers, chunking exceptions, cleaning frontiers, and cleaning
+exceptions. Chunking data are stored in three hashtbles according to
+their types: inflected form in C<IF> field, lemmatized form in C<LF>
+field, and part-of-speech tags in C<POS> field.
 
 =head1 METHODS
 
 
 =head2 new()
 
+    new();
+
+The method creates a new empty chunking data subset.
 
 =head2 getIF()
 
+    getIF();
+
+The method returns the reference to the hashtable of inflected forms.
 
 =head2 getPOS()
 
+    getPOS();
+
+The method returns the reference to the hashtable of Part-of-Speech tags.
 
 =head2 getLF()
 
+    getLF();
+
+The method returns the reference to the hashtable of lemmatized forms.
 
 =head2 getSome()
 
+    getSome($type);
+
+The method returns the reference to the hashtable of the field defined
+by C<$type>.
 
 =head2 addIF()
 
+    addIF($value);
+
+The method adds C<$value> to the inflected form field of the chuncking
+subset.
 
 =head2 addPOS()
 
+    addPOS($value);
+
+The method adds C<$value> to the Part-of-Speech field of the chuncking
+subset.
+
 
 =head2 addLF()
 
+    addLF($value);
+
+The method adds C<$value> to the lemmatized form field of the chuncking
+subset.
 
 =head2 addSome()
 
+    addSome($type,$value);
+
+The method adds information related to the type C<$type> (i.e. IF --
+inflected form, LF -- lemmatized form, POS -- Part-of-Speech tagqq)
+with the value C<$Value>.
 
 =head2 existData()
 
+The methods checks if the value C<$value> exists in the field
+C<$type>. It returns 1 if it exists, otherwise 0.
+
 
 =head1 SEE ALSO
 
@@ -133,7 +175,7 @@ Terminological Resources. In Advances in Natural Language Processing
 
 =head1 AUTHOR
 
-Thierry Hamon <thierry.hamon@lipn.univ-paris13.fr> and Sophie Aubin <sophie.aubin@lipn.univ-paris13.fr>
+Thierry Hamon <thierry.hamon@univ-paris13.fr> and Sophie Aubin <sophie.aubin@lipn.univ-paris13.fr>
 
 =head1 COPYRIGHT AND LICENSE
 
